#!/bin/sh

# Bail out unless this is running on a Mennekes board

if ! grep -qi mennekes /home/charge/persistency/ChargePointVendor_branding 2>/dev/null; then
	exit
fi

# Also bail out if GPIO B23 doesn't control USB power

if ! grep -q '\(1\?612\)\|\(NEB\)' /dev/ebee_variant 2>/dev/null; then
    exit
fi

stop=0
trap "stop=1" HUP

while true; do
	sleep 10

	# If 'stop' is non-zero we got a SIGHUP signal, probably from
	# mdev.action.add

	if [ $stop -ne 0 ] ; then
		logger "recover_eth0.sh: stop was triggered from mdev"
		exit
	fi

    # Test if eth0 exists, in that case we can exit

	if ifconfig eth0 > /dev/null 2>&1; then
		logger "recover_eth0.sh: ethernet device exists"
		exit
	fi

	# Also bail out if eth0 disappeared but instead a block device appeared

	if [ -d /proc/scsi/usb-storage ] ; then
		logger "recover_eth0.sh: block device detected - stopping"
		exit
	fi

	# Try to get eth0 back by toggling the GPIO named 'GPIO_USB_HOST_POWER_ON'

	logger "recover_eth0.sh: power-cycling USB-host"
	export_gpio 55
	echo low > /sys/class/gpio/pioB23/direction
	usleep 100000
	echo high > /sys/class/gpio/pioB23/direction
done
